@@ -44,7 +44,7 @@ def inside_git_repo() -> bool:
 
 # Check if the worktree is dirty.
 def is_worktree_dirty() -> bool:
-    return subprocess.check_output(['git', 'status', '--porcelain']) != b''
+    return subprocess.check_output(['git', 'status', '--porcelain', '--untracked-files=no']) != b''
 
 # Get length of abbreviated git commit hash
 def get_abbrev_hash_length() -> int:
@@ -162,10 +162,13 @@ class RelativeMetricAcceptanceWindow(MetricAcceptanceWindow):
         return (lowerBound, upperBound)
 
     def describe(self) -> str:
-        return '+/- %1.1f%%' % (100*self.__tol)
+        return '+/- %1.1f%%' % (self.__tol)
 
 def parse_perf_stat(stat_str: str) -> PerfStat:
     field_vals = stat_str.strip('\t').split('\t')
+    if len(field_vals) != 5:
+        raise ValueError(f'Invalid stat line: {field_vals}')
+
     stat = PerfStat(*field_vals) # type: ignore
     if stat.test_env.startswith('"') and stat.test_env.endswith('"'):
         # Due to a bug, in historical data sometimes the test_env
@@ -184,11 +187,14 @@ def get_perf_stats(commit: Union[GitRef, GitHash]=GitRef('HEAD'),
     except subprocess.CalledProcessError:
         return []
 
-    return \
-        [ parse_perf_stat(stat_str)
-          for stat_str in log.strip('\n').split('\n')
-          if stat_str != ''
-        ]
+    try:
+        return \
+            [ parse_perf_stat(stat_str)
+              for stat_str in log.strip('\n').split('\n')
+              if stat_str != ''
+            ]
+    except ValueError as e:
+        raise ValueError(f'Invalid stat line for commit {commit}')
 
 # Check if a str is in a 40 character git commit hash.
 _commit_hash_re = re.compile('[0-9a-f]' * 40)
